@@ -53,6 +53,8 @@
 DCORE_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 
+const bool IsWayland = qgetenv("XDG_SESSION_TYPE").contains("wayland");
+
 //Load the System cursor --begin
 static XcursorImages*
 xcLoadImages(const char *image, int size)
@@ -170,8 +172,38 @@ static double get_scale_ratio() {
     return scaleRatio;
 }
 
+// 读取系统配置文件的缩放比，如果是null，默认返回1
+double getScaleFormConfig()
+{
+    QDBusInterface configInter("com.deepin.system.Display",
+                                                     "/com/deepin/system/Display",
+                                                     "com.deepin.system.Display",
+                                                    QDBusConnection::systemBus());
+    if (!configInter.isValid()) {
+        return 1;
+    }
+    QDBusReply<QString> configReply = configInter.call("GetConfig");
+    if (configReply.error().message().isEmpty()) {
+        QString config = configReply.value();
+        QJsonParseError jsonError;
+        QJsonDocument jsonDoc(QJsonDocument::fromJson(config.toStdString().data(), &jsonError));
+        if (jsonError.error == QJsonParseError::NoError) {
+            QJsonObject rootObj = jsonDoc.object();
+            QJsonObject Config = rootObj.value("Config").toObject();
+            double scaleFactors = Config.value("ScaleFactors").toObject().value("ALL").toDouble();
+            qDebug() << "scaleFactors :" << scaleFactors;
+            return scaleFactors;
+        } else {
+            return 1;
+        }
+    } else {
+        qWarning() << configReply.error().message();
+        return 1;
+    }
+}
+
 static void set_auto_QT_SCALE_FACTOR() {
-    const double ratio = get_scale_ratio();
+    const double ratio = IsWayland ? getScaleFormConfig() : get_scale_ratio();
     if (ratio > 0.0) {
         setenv("QT_SCALE_FACTOR", QByteArray::number(ratio).constData(), 1);
     }
@@ -220,7 +252,7 @@ int main(int argc, char* argv[])
 
     DGuiApplicationHelper::setAttribute(DGuiApplicationHelper::UseInactiveColorGroup, false);
     // 设置缩放，文件存在的情况下，由后端去设置，否则前端自行设置
-    if (!QFile::exists("/etc/lightdm/deepin/xsettingsd.conf")) {
+    if (!QFile::exists("/etc/lightdm/deepin/xsettingsd.conf") || IsWayland) {
         set_auto_QT_SCALE_FACTOR();
     }
 
@@ -228,8 +260,6 @@ int main(int argc, char* argv[])
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     qApp->setOrganizationName("deepin");
     qApp->setApplicationName("org.deepin.dde.lightdm-deepin-greeter");
-    qApp->setApplicationVersion("2015.1.0");
-    qApp->setAttribute(Qt::AA_ForceRasterWidgets);
 
     set_pointer();
 
@@ -314,7 +344,11 @@ int main(int argc, char* argv[])
         QObject::connect(loginFrame, &LoginWindow::requestEndAuthentication, worker, &GreeterWorker::endAuthentication);
         QObject::connect(loginFrame, &LoginWindow::authFinished, worker, &GreeterWorker::onAuthFinished);
         QObject::connect(worker, &GreeterWorker::requestUpdateBackground, loginFrame, &LoginWindow::updateBackground);
-        loginFrame->show();
+        if (!IsWayland) {
+            loginFrame->show();
+        } else {
+            QObject::connect(worker, &GreeterWorker::showLoginWindow, loginFrame, &LoginWindow::setVisible);
+        }
         return loginFrame;
     };
 
@@ -330,7 +364,9 @@ int main(int argc, char* argv[])
     checker.start();
 #endif
 
-    model->setVisible(true);
+    if (!IsWayland) {
+        model->setVisible(true);
+    }
 
     return a.exec();
 }
