@@ -5,6 +5,7 @@
 #include "userinfo.h"
 
 #include <DSysInfo>
+#include <DGuiApplicationHelper>
 
 #include <QGSettings>
 
@@ -21,6 +22,7 @@ using PowerInter = com::deepin::system::Power;
 using namespace Auth;
 using namespace AuthCommon;
 DCORE_USE_NAMESPACE
+DGUI_USE_NAMESPACE
 
 const int NUM_LOCKED = 0;   // 禁用小键盘
 const int NUM_UNLOCKED = 1; // 启用小键盘
@@ -32,6 +34,9 @@ GreeterWorker::GreeterWorker(SessionBaseModel *const model, QObject *parent)
     , m_authFramework(new DeepinAuthFramework(this))
     , m_lockInter(new DBusLockService(LOCKSERVICE_NAME, LOCKSERVICE_PATH, QDBusConnection::systemBus(), this))
     , m_soundPlayerInter(new SoundThemePlayerInter("com.deepin.api.SoundThemePlayer", "/com/deepin/api/SoundThemePlayer", QDBusConnection::systemBus(), this))
+#ifdef USE_DEEPIN_WAYLAND
+    , m_greeterDisplayWayland(nullptr)
+#endif
     , m_resetSessionTimer(new QTimer(this))
     , m_limitsUpdateTimer(new QTimer(this))
     , m_retryAuth(false)
@@ -43,6 +48,23 @@ GreeterWorker::GreeterWorker(SessionBaseModel *const model, QObject *parent)
     }
 #endif
 
+#ifdef USE_DEEPIN_WAYLAND
+    if (!DGuiApplicationHelper::isXWindowPlatform()) {
+        m_greeterDisplayWayland = new GreeterDisplayWayland();
+        connect(m_greeterDisplayWayland, &GreeterDisplayWayland::setOutputStart, this, [=] {
+            Q_EMIT showLoginWindow(false);
+            model->setVisible(false);
+        });
+        connect(m_greeterDisplayWayland, &GreeterDisplayWayland::setOutputFinished, this, [=] {
+            QTimer::singleShot(100, this, [this, model] { // 延时显示是为了避免分辨率改变的过程被展示出来
+                Q_EMIT showLoginWindow(true);
+                model->setVisible(true);
+            });
+        });
+        m_greeterDisplayWayland->start();
+    }
+#endif
+
     checkDBusServer(m_accountsInter->isValid());
 
     initConnections();
@@ -74,6 +96,11 @@ GreeterWorker::GreeterWorker(SessionBaseModel *const model, QObject *parent)
 
 GreeterWorker::~GreeterWorker()
 {
+#ifdef USE_DEEPIN_WAYLAND
+    if(m_greeterDisplayWayland) {
+       m_greeterDisplayWayland->deleteLater();
+    }
+#endif
 }
 
 void GreeterWorker::initConnections()
@@ -118,6 +145,8 @@ void GreeterWorker::initConnections()
     connect(m_authFramework, &DeepinAuthFramework::MFAFlagChanged, m_model, &SessionBaseModel::updateMFAFlag);
     connect(m_authFramework, &DeepinAuthFramework::PINLenChanged, m_model, &SessionBaseModel::updatePINLen);
     connect(m_authFramework, &DeepinAuthFramework::PromptChanged, m_model, &SessionBaseModel::updatePrompt);
+    connect(m_authFramework, &DeepinAuthFramework::SessionCreated, this, &GreeterWorker::onSessionCreated);
+
     /* org.freedesktop.login1.Session */
     connect(m_login1SessionSelf, &Login1SessionSelf::ActiveChanged, this, [=](bool active) {
         qInfo() << "Login1SessionSelf::ActiveChanged:" << active;
@@ -133,6 +162,12 @@ void GreeterWorker::initConnections()
             destoryAuthentication(m_account);
         }
     });
+
+    connect(m_login1Inter, &DBusLogin1Manager::PrepareForSleep, this, [ = ](bool active) {
+        qDebug() << "set dpms: " << (!active ? "on" : "off");
+        screenSwitchByWldpms(!active);
+    });
+
     /* org.freedesktop.login1.Manager */
     connect(m_login1Inter, &DBusLogin1Manager::PrepareForSleep, this, [=](bool isSleep) {
         qInfo() << "DBusLogin1Manager::PrepareForSleep:" << isSleep;
@@ -437,9 +472,6 @@ void GreeterWorker::createAuthentication(const QString &account)
     case Available:
         m_authFramework->CreateAuthController(account, m_authFramework->GetSupportedMixAuthFlags(), Login);
         m_authFramework->SetAuthQuitFlag(account, DeepinAuthFramework::ManualQuit);
-        if (!m_authFramework->SetPrivilegesEnable(account, QString("/usr/sbin/lightdm"))) {
-            qWarning() << "Failed to set privileges!";
-        }
         startGreeterAuth(account);
         break;
     default:
@@ -545,8 +577,7 @@ void GreeterWorker::endAuthentication(const QString &account, const int authType
  */
 void GreeterWorker::checkAccount(const QString &account)
 {
-    qDebug() << "GreeterWorker::checkAccount:" << account;
-    if (m_greeter->authenticationUser() == account) {
+    if (m_greeter->authenticationUser() == account && m_account == account) {
         return;
     }
 
@@ -830,6 +861,14 @@ void GreeterWorker::onCurrentUserChanged(const std::shared_ptr<User> &user)
 {
     recoveryUserKBState(user);
     loadTranslation(user->locale());
+    emit requestUpdateBackground(m_model->currentUser()->greeterBackground());
+}
+
+void GreeterWorker::onSessionCreated()
+{
+    if (!m_authFramework->SetPrivilegesEnable(m_account, QString("/usr/sbin/lightdm"))) {
+        qWarning() << "Failed to set privileges!";
+    }
 }
 
 void GreeterWorker::saveNumlockState(std::shared_ptr<User> user, bool on)
@@ -893,6 +932,8 @@ void GreeterWorker::restartResetSessionTimer()
 
 void GreeterWorker::startGreeterAuth(const QString &account)
 {
+
+    qInfo() << Q_FUNC_INFO << account ;
     m_greeter->authenticate(account);
 }
 
@@ -901,3 +942,16 @@ void GreeterWorker::changePasswd()
     m_model->updateMFAFlag(false);
     m_model->setAuthType(AT_PAM);
 }
+
+void GreeterWorker::screenSwitchByWldpms(bool active)
+{
+    qDebug() << "GreeterWorker::screenSwitchByWldpms:" << active;
+    QStringList arguments;
+    arguments << "-s";
+    if (active) {
+        arguments << "on";
+    } else {
+        arguments << "off";
+    }
+    QProcess::startDetached("dde_wldpms", arguments);
+}
