@@ -463,6 +463,7 @@ void AuthPassword::showResetPasswordMessage()
     m_resetPasswordFloatingMessage->setPalette(pa);
     m_resetPasswordFloatingMessage->setIcon(QIcon::fromTheme("dialog-warning"));
     DSuggestButton *suggestButton = new DSuggestButton(tr("Reset Password"));
+    suggestButton->setAutoDefault(true);
     m_resetPasswordFloatingMessage->setWidget(suggestButton);
     m_resetPasswordFloatingMessage->setMessage(tr("Forgot password?"));
     connect(suggestButton, &QPushButton::clicked, this, [ this ] {
@@ -602,6 +603,24 @@ void AuthPassword::hideEvent(QHideEvent *event)
     AuthModule::hideEvent(event);
 }
 
+void AuthPassword::showEvent(QShowEvent *event)
+{
+    m_passwordHintBtn->setVisible(m_limitsInfo->numFailures > 0 && !m_passwordHint.isEmpty());
+    if (m_limitsInfo->locked) {
+        setAuthState(AS_Locked, "Locked");
+        if (QFile::exists(ResetPassword_Exe_Path) && m_currentUid <= 9999 && !IsCommunitySystem ) {
+            qDebug() << "begin reset passoword";
+            setResetPasswordMessageVisible(true);
+            updateResetPasswordUI();
+        }
+    } else {
+        setResetPasswordMessageVisible(false);
+        updateResetPasswordUI();
+    }
+
+    AuthModule::showEvent(event);
+}
+
 void AuthPassword::setAuthStatueVisible(bool visible)
 {
     m_showAuthState = visible;
