@@ -71,7 +71,7 @@ AuthSingle::AuthSingle(QWidget *parent)
  */
 void AuthSingle::initUI()
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    auto *mainLayout = new QHBoxLayout(this);
     mainLayout->setSpacing(0);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -80,9 +80,9 @@ void AuthSingle::initUI()
     m_lineEdit->setContextMenuPolicy(Qt::NoContextMenu);
     m_lineEdit->setFocusPolicy(Qt::StrongFocus);
     m_lineEdit->lineEdit()->setAlignment(Qt::AlignCenter);
-    m_lineEdit->lineEdit()->setValidator(new QRegExpValidator(QRegExp("^[ -~]+$")));
+    m_lineEdit->lineEdit()->setValidator(new QRegExpValidator(QRegExp("^[ -~]+$"), this));
 
-    QHBoxLayout *passwordLayout = new QHBoxLayout(m_lineEdit->lineEdit());
+    auto *passwordLayout = new QHBoxLayout(m_lineEdit->lineEdit());
     passwordLayout->setContentsMargins(0, 0, 10, 0);
     passwordLayout->setSpacing(0);
     /* 键盘布局按钮 */
@@ -268,7 +268,7 @@ void AuthSingle::setAnimationState(const bool start)
  */
 void AuthSingle::setLimitsInfo(const LimitsInfo &info)
 {
-    qDebug() << "AuthSingle::setLimitsInfo" << info.unlockTime;
+    qDebug() << "AuthSingle::setLimitsInfo" << info.numFailures;
     const bool lockStateChanged = (info.locked != m_limitsInfo->locked);
     AuthModule::setLimitsInfo(info);
     setPasswordHintBtnVisible(info.numFailures > 0 && !m_passwordHint.isEmpty());
@@ -460,6 +460,7 @@ void AuthSingle::showResetPasswordMessage()
     m_resetPasswordFloatingMessage->setPalette(pa);
     m_resetPasswordFloatingMessage->setIcon(QIcon::fromTheme("dialog-warning"));
     DSuggestButton *suggestButton = new DSuggestButton(tr("Reset Password"));
+    suggestButton->setAutoDefault(true);
     m_resetPasswordFloatingMessage->setWidget(suggestButton);
     m_resetPasswordFloatingMessage->setMessage(tr("Forgot password?"));
     connect(suggestButton, &QPushButton::clicked, this, [ this ]{
