@@ -23,6 +23,7 @@ AuthInterface::AuthInterface(SessionBaseModel *const model, QObject *parent)
     , m_authenticateInter(new Authenticate("com.deepin.daemon.Authenticate", "/com/deepin/daemon/Authenticate", QDBusConnection::systemBus(), this))
     , m_dbusInter(new DBusObjectInter("org.freedesktop.DBus", "/org/freedesktop/DBus", QDBusConnection::systemBus(), this))
     , m_lastLogoutUid(0)
+    , m_currentUserUid(0)
     , m_loginUserList(0)
 {
     if (m_login1Inter->isValid()) {
@@ -32,10 +33,6 @@ AuthInterface::AuthInterface(SessionBaseModel *const model, QObject *parent)
     } else {
         qWarning() << "m_login1Inter:" << m_login1Inter->lastError().type();
     }
-
-    if (m_model->appType() != Login && QGSettings::isSchemaInstalled("com.deepin.dde.session-shell")) {
-        m_gsettings = new QGSettings("com.deepin.dde.session-shell", "/com/deepin/dde/session-shell/", this);
-    }
 }
 
 void AuthInterface::setKeyboardLayout(std::shared_ptr<User> user, const QString &layout)
@@ -133,9 +130,8 @@ void AuthInterface::onLoginUserListChanged(const QString &list)
     m_loginUserList.clear();
 
     std::list<uint> availableUidList;
-    for (std::shared_ptr<User> user : m_model->userList()) {
-        availableUidList.push_back(user->uid());
-    }
+    std::transform(std::begin(m_model->userList()), std::end(m_model->userList()), std::back_inserter(availableUidList),
+                   [](std::shared_ptr<User> user) -> uint { return user->uid(); });
 
     QJsonObject userList = QJsonDocument::fromJson(list.toUtf8()).object();
     for (auto it = userList.constBegin(); it != userList.constEnd(); ++it) {
@@ -202,10 +198,8 @@ QVariant AuthInterface::getGSettings(const QString& node, const QString& key)
 
 bool AuthInterface::isLogined(uint uid)
 {
-    auto isLogind = std::find_if(m_loginUserList.begin(), m_loginUserList.end(),
-                                 [=] (uint UID) { return uid == UID; });
-
-    return isLogind != m_loginUserList.end();
+    return std::any_of(m_loginUserList.begin(), m_loginUserList.end(),
+                       [uid](const uint UID) { return UID == uid; });
 }
 
 bool AuthInterface::isDeepin()
