@@ -39,6 +39,9 @@ public:
     void autoUnlock();
     int getTopSpacing() const override;
 
+protected:
+    void resizeEvent(QResizeEvent *event);
+
 private:
     void initUI();
     void initConnections();
