@@ -1,3 +1,4 @@
+
 /*
 * Copyright (C) 2021 ~ 2021 Uniontech Software Technology Co.,Ltd.
 *
@@ -43,6 +44,8 @@
 const QSize AuthButtonSize(60, 36);
 const QSize AuthButtonIconSize(24, 24);
 
+QList<SFAWidget*> SFAWidget::SFAWidgetObjs = {};
+
 SFAWidget::SFAWidget(QWidget *parent)
     : AuthWidget(parent)
     , m_mainLayout(new QVBoxLayout(this))
@@ -52,12 +55,21 @@ SFAWidget::SFAWidget(QWidget *parent)
     , m_bioAuthStatePlaceHolder(new QSpacerItem(0, BIO_AUTH_STATE_PLACE_HOLDER_HEIGHT))
     , m_bioBottomSpacingHolder(new QSpacerItem(0, BIO_AUTH_STATE_BOTTOM_SPACING))
     , m_authTypeBottomSpacingHolder(new QSpacerItem(0, CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING))
+    , m_currentAuthType(AT_All)
+    , m_inited(false)
 {
     setObjectName(QStringLiteral("SFAWidget"));
     setAccessibleName(QStringLiteral("SFAWidget"));
 
     setGeometry(0, 0, 280, 176);
     setMinimumSize(280, 176);
+
+    SFAWidgetObjs.append(this);
+}
+
+SFAWidget::~SFAWidget()
+{
+    SFAWidgetObjs.removeAll(this);
 }
 
 void SFAWidget::initUI()
@@ -117,8 +129,11 @@ void SFAWidget::setModel(const SessionBaseModel *model)
     initUI();
     initConnections();
 
-    setAuthType(model->getAuthProperty().AuthType);
+    // 在登陆设置验证类型的时候需要判断当前是否是"..."账户，需要先设置当前用户，在设置验证类型，两者的顺序切勿颠倒。
     setUser(model->currentUser());
+    setAuthType(model->getAuthProperty().AuthType);
+
+    m_inited = true;
 }
 
 /**
@@ -127,69 +142,32 @@ void SFAWidget::setModel(const SessionBaseModel *model)
  */
 void SFAWidget::setAuthType(const int type)
 {
-    qDebug() << "SFAWidget::setAuthType:" << type;
-    if (type & AT_Password) {
-        initPasswdAuth();
-    } else if (m_passwordAuth) {
-        delete m_passwordAuth;
-        m_passwordAuth = nullptr;
-        m_authButtons.value(AT_Password)->deleteLater();
-        m_authButtons.remove(AT_Password);
-        m_frameDataBind->clearValue("SFPasswordAuthState");
-        m_frameDataBind->clearValue("SFPasswordAuthMsg");
-    }
-    if (type & AT_Face) {
-        initFaceAuth();
-    } else if (m_faceAuth) {
-        delete m_faceAuth;
-        m_faceAuth = nullptr;
-        m_authButtons.value(AT_Face)->deleteLater();
-        m_authButtons.remove(AT_Face);
-        m_frameDataBind->clearValue("SFFaceAuthState");
-        m_frameDataBind->clearValue("SFFaceAuthMsg");
-    }
-    if (type & AT_Iris) {
-        initIrisAuth();
-    } else if (m_irisAuth) {
-        delete m_irisAuth;
-        m_irisAuth = nullptr;
-        m_authButtons.value(AT_Iris)->deleteLater();
-        m_authButtons.remove(AT_Iris);
-        m_frameDataBind->clearValue("SFIrisAuthState");
-        m_frameDataBind->clearValue("SFIrisAuthMsg");
-    }
-    if (type & AT_Fingerprint) {
-        initFingerprintAuth();
-    } else if (m_fingerprintAuth) {
-        delete m_fingerprintAuth;
-        m_fingerprintAuth = nullptr;
-        m_authButtons.value(AT_Fingerprint)->deleteLater();
-        m_authButtons.remove(AT_Fingerprint);
-        m_frameDataBind->clearValue("SFFingerprintAuthState");
-        m_frameDataBind->clearValue("SFFingerprintAuthMsg");
-    }
-    if (type & AT_Ukey) {
-        initUKeyAuth();
-    } else if (m_ukeyAuth) {
-        delete m_ukeyAuth;
-        m_ukeyAuth = nullptr;
-        m_authButtons.value(AT_Ukey)->deleteLater();
-        m_authButtons.remove(AT_Ukey);
-        m_frameDataBind->clearValue("SFUKeyAuthState");
-        m_frameDataBind->clearValue("SFUKeyAuthMsg");
-    }
-    if (type & AT_PAM) {
-        initSingleAuth();
-    } else if (m_singleAuth) {
-        delete m_singleAuth;
-        m_singleAuth = nullptr;
-        m_authButtons.value(AT_PAM)->deleteLater();
-        m_authButtons.remove(AT_PAM);
-        m_frameDataBind->clearValue("SFSingleAuthState");
-        m_frameDataBind->clearValue("SFSingleAuthMsg");
-    }
-    if (dss::module::ModulesLoader::instance().findModulesByType(dss::module::BaseModuleInterface::LoginType).size() > 0) {
+    qDebug() << Q_FUNC_INFO << "SFAWidget::setAuthType:" << type;
+    int authType = type;
+    if (dss::module::ModulesLoader::instance().findModulesByType(dss::module::BaseModuleInterface::LoginType).size() > 0
+            && !m_model->currentUser()->isNoPasswordLogin() && !m_model->currentUser()->isAutomaticLogin()) {
+        authType |= AT_Custom;
         initCustomAuth();
+
+        // 只有当首次创建sfa或者这个对象已经初始化过了才应用DefaultAuthLevel
+        // 这是只是一个规避方案，主要是因为每个屏幕都会创建一个sfa，这看起来不太合理，特别是处理单例对象时，带来很大的不便。
+
+        // TODO 每个屏幕只创建一个LockContent，鼠标在屏幕间移动的时候重新设置LockContent的parent即可。
+        qInfo() << "Sfa is inited: " << m_inited << ", sfa widgets size: " << SFAWidgetObjs.size();
+        if (m_inited || SFAWidgetObjs.size() <= 1) {
+             qInfo() << Q_FUNC_INFO << "m_customAuth->authType()" << m_customAuth->authType();
+            if (m_customAuth->defaultAuthLevel() == AuthCommon::DefaultAuthLevel::Default) {
+                m_currentAuthType = m_currentAuthType == AT_All ? AT_Custom : m_currentAuthType;
+            } else if (m_customAuth->defaultAuthLevel() == AuthCommon::DefaultAuthLevel::StrongDefault) {
+                if (m_currentAuthType == AT_All || m_currentAuthType == AT_Custom) {
+                    m_currentAuthType = m_customAuth->authType();
+                }
+            }
+        }
+
+        if (type == AT_None && m_user->type() == User::Default) {
+            initAccount();
+        }
     } else if (m_customAuth) {
         delete m_customAuth;
         m_customAuth = nullptr;
@@ -199,6 +177,77 @@ void SFAWidget::setAuthType(const int type)
         m_frameDataBind->clearValue("SFCustomAuthMsg");
     }
 
+    if (type != AT_None || !m_customAuth || m_user->type() != User::Default) {
+        auto btn = m_authButtons.value(AT_None);
+        if (btn) {
+            btn->deleteLater();
+            btn = nullptr;
+            m_authButtons.remove(AT_None);
+        }
+    }
+
+    if (authType & AT_Password) {
+        initPasswdAuth();
+    } else if (m_passwordAuth) {
+        delete m_passwordAuth;
+        m_passwordAuth = nullptr;
+        m_authButtons.value(AT_Password)->deleteLater();
+        m_authButtons.remove(AT_Password);
+        m_frameDataBind->clearValue("SFPasswordAuthState");
+        m_frameDataBind->clearValue("SFPasswordAuthMsg");
+    }
+    if (authType & AT_Face) {
+        initFaceAuth();
+    } else if (m_faceAuth) {
+        delete m_faceAuth;
+        m_faceAuth = nullptr;
+        m_authButtons.value(AT_Face)->deleteLater();
+        m_authButtons.remove(AT_Face);
+        m_frameDataBind->clearValue("SFFaceAuthState");
+        m_frameDataBind->clearValue("SFFaceAuthMsg");
+    }
+    if (authType & AT_Iris) {
+        initIrisAuth();
+    } else if (m_irisAuth) {
+        delete m_irisAuth;
+        m_irisAuth = nullptr;
+        m_authButtons.value(AT_Iris)->deleteLater();
+        m_authButtons.remove(AT_Iris);
+        m_frameDataBind->clearValue("SFIrisAuthState");
+        m_frameDataBind->clearValue("SFIrisAuthMsg");
+    }
+    if (authType & AT_Fingerprint) {
+        initFingerprintAuth();
+    } else if (m_fingerprintAuth) {
+        delete m_fingerprintAuth;
+        m_fingerprintAuth = nullptr;
+        m_authButtons.value(AT_Fingerprint)->deleteLater();
+        m_authButtons.remove(AT_Fingerprint);
+        m_frameDataBind->clearValue("SFFingerprintAuthState");
+        m_frameDataBind->clearValue("SFFingerprintAuthMsg");
+    }
+    if (authType & AT_Ukey) {
+        initUKeyAuth();
+    } else if (m_ukeyAuth) {
+        delete m_ukeyAuth;
+        m_ukeyAuth = nullptr;
+        m_authButtons.value(AT_Ukey)->deleteLater();
+        m_authButtons.remove(AT_Ukey);
+        m_frameDataBind->clearValue("SFUKeyAuthState");
+        m_frameDataBind->clearValue("SFUKeyAuthMsg");
+    }
+    if (authType & AT_PAM) {
+        initSingleAuth();
+    } else if (m_singleAuth) {
+        delete m_singleAuth;
+        m_singleAuth = nullptr;
+        m_authButtons.value(AT_PAM)->deleteLater();
+        m_authButtons.remove(AT_PAM);
+        m_frameDataBind->clearValue("SFSingleAuthState");
+        m_frameDataBind->clearValue("SFSingleAuthMsg");
+    }
+
+    m_chooseAuthButtonBox->setEnabled(true);
     const int count = m_authButtons.values().size();
     if (count > 0) {
         m_chooseAuthButtonBox->setButtonList(m_authButtons.values(), true);
@@ -209,7 +258,17 @@ void SFAWidget::setAuthType(const int type)
         }
         if (count > 1) {
             m_chooseAuthButtonBox->show();
-            if (type & m_user->lastAuthType()) {
+            if (m_customAuth && (authType & m_currentAuthType) && m_currentAuthType != AT_All) {
+                if (m_chooseAuthButtonBox->checkedId() == m_currentAuthType) {
+                    if (m_chooseAuthButtonBox->button(m_currentAuthType)) {
+                        emit m_chooseAuthButtonBox->button(m_currentAuthType)->toggled(true);
+                    } else {
+                        m_authButtons.value(m_currentAuthType)->setChecked(true);
+                    }
+                } else {
+                    m_authButtons.value(m_currentAuthType)->setChecked(true);
+                }
+            } else if (authType & m_user->lastAuthType()) {
                 if (m_chooseAuthButtonBox->checkedId() == m_user->lastAuthType()) {
                     emit m_chooseAuthButtonBox->button(m_user->lastAuthType())->toggled(true);
                 } else {
@@ -236,6 +295,12 @@ void SFAWidget::setAuthType(const int type)
         m_chooseAuthButtonBox->hide();
     }
 
+    if (m_customAuth && !m_customAuth->showSwithButton()) {
+        m_chooseAuthButtonBox->button(AT_Custom)->hide();
+        if (count <= 2)
+            m_chooseAuthButtonBox->hide();
+    }
+
     if (m_model->currentUser()->isNoPasswordLogin()) {
         m_lockButton->setEnabled(true);
         setFocusProxy(m_lockButton);
@@ -296,6 +361,15 @@ void SFAWidget::setAuthState(const int type, const int state, const QString &mes
             m_frameDataBind->updateValue("SFSingleAuthState", state);
             m_frameDataBind->updateValue("SFSingleAuthMsg", message);
         }
+
+        // 这里是为了让自定义登陆知道ligthdm已经开启验证了
+        qInfo() << "Current auth type is: " << m_currentAuthType;
+        if (m_customAuth && state == AS_Prompt && m_currentAuthType == AT_Custom) {
+            // 有可能DA发送了验证开始，但是lightdm的验证还未开始，此时发送token的话lightdm无法验证通过。
+            // ligthdm的pam发送prompt后则认为lightdm的pam已经开启验证
+            qInfo() << "Greeter is in authentication";
+            m_customAuth->lightdmAuthStarted();
+        }
         break;
     case AT_Custom:
         if (m_customAuth) {
@@ -694,6 +768,7 @@ void SFAWidget::initIrisAuth()
  */
 void SFAWidget::initCustomAuth()
 {
+    qDebug() << Q_FUNC_INFO << "init custom auth";
     if (m_customAuth) {
         return;
     }
@@ -701,23 +776,42 @@ void SFAWidget::initCustomAuth()
     m_customAuth = new AuthCustom(this);
 
     dss::module::LoginModuleInterface *module = dynamic_cast<dss::module::LoginModuleInterface *>(dss::module::ModulesLoader::instance().findModulesByType(0).values().first());
-    module->init();
     m_customAuth->setModule(module);
+    m_customAuth->setModel(m_model);
+    m_customAuth->initUi();
     m_customAuth->hide();
 
-    connect(m_customAuth, &AuthCustom::requestAuthenticate, this, [this] {
+    connect(m_customAuth, &AuthCustom::requestSendToken, this, [this] (const QString &token) {
         m_lockButton->setEnabled(false);
-        emit sendTokenToAuth(m_user->name(), AT_Custom, "");
+        qInfo() << "sfa custom sendToken name :" <<  m_user->name() << "token:" << token;
+        Q_EMIT sendTokenToAuth(m_user->name(), AT_Custom, token);
     });
     connect(m_customAuth, &AuthCustom::authFinished, this, [ this ] (const int authStatus) {
         if (authStatus == AS_Success) {
             m_lockButton->setEnabled(true);
         }
     });
+    connect(m_customAuth, &AuthCustom::requestCheckAccount, this, [this] (const QString &account) {
+        qInfo() << "Request check account: " << account;
+        if (m_user && m_user->name() == account) {
+            dss::module::AuthCallbackData data = m_customAuth->getCurrentAuthData();
+            if (data.result == dss::module::Success)
+                Q_EMIT sendTokenToAuth(m_user->name(), AT_Custom, QString::fromStdString(data.token));
+            else
+                qWarning() << Q_FUNC_INFO << "auth failed";
+
+            return;
+        }
+
+        Q_EMIT requestCheckAccount(account);
+    });
+
+    connect(m_customAuth, &AuthCustom::notifyAuthTypeChange, this, &SFAWidget::onRequestChangeAuth);
 
     /* 认证选择按钮 */
     DButtonBoxButton *btn = new DButtonBoxButton(DStyle::SP_SelectElement, QString(), this);
-    const QIcon icon(QString::fromStdString(module->icon()));
+    const QString &iconStr = QString::fromStdString(module->icon());
+    const QIcon icon = QFile::exists(iconStr) ? QIcon(iconStr) : QIcon::fromTheme(iconStr);
     if (!icon.isNull()) {
         btn->setIcon(icon);
     }
@@ -725,19 +819,30 @@ void SFAWidget::initCustomAuth()
     btn->setFixedSize(AuthButtonSize);
     btn->setFocusPolicy(Qt::NoFocus);
     m_authButtons.insert(AT_Custom, btn);
-    connect(btn, &DButtonBoxButton::toggled, this, [this](const bool checked) {
+    connect(btn, &DButtonBoxButton::toggled, this, [this, module](const bool checked) {
         if (checked) {
-            replaceWidget(m_customAuth);
-            m_frameDataBind->updateValue("SFAType", AT_Custom);
+            qDebug() << Q_FUNC_INFO << "Custom auth is checked";
             m_biometricAuthState->hide();
             setBioAuthStateVisible(nullptr, false);
-            emit requestStartAuthentication(m_user->name(), AT_Custom);
-            m_nameLabel->hide();
+            m_accountEdit->hide();
+            m_userAvatar->setVisible(m_customAuth->showAvatar());
+            m_nameLabel->setVisible(m_customAuth->showUserName());
+            m_lockButton->setVisible(m_customAuth->showLockButton());
+            replaceWidget(m_customAuth);
+            m_frameDataBind->updateValue("SFAType", AT_Custom);
+            Q_EMIT requestStartAuthentication(m_user->name(), AT_Custom);
         } else {
             m_customAuth->hide();
             m_nameLabel->show();
+            m_userAvatar->show();
+            m_lockButton->show();
             m_lockButton->setEnabled(false);
-            emit requestEndAuthentication(m_user->name(), AT_Custom);
+            if (m_user->type() == User::Default) {
+                m_nameLabel->hide();
+                m_accountEdit->show();
+                m_accountEdit->setFocus();
+            }
+            Q_EMIT requestEndAuthentication(m_user->name(), AT_Custom);
         }
     });
 }
@@ -761,10 +866,19 @@ void SFAWidget::checkAuthResult(const int type, const int state)
             if (m_irisAuth) m_irisAuth->setAuthState(AS_Ended, "Ended");
             emit authFinished();
         }
+
+        if (m_customAuth) {
+            m_customAuth->reset();
+        }
     } else if (type != AT_All && state == AS_Success) {
         m_user->setLastAuthType(type);
         m_lockButton->setEnabled(true);
         m_lockButton->setFocus();
+
+        if (type == AT_Face || type == AT_Iris) {
+            // 禁止切换其他认证方式
+            m_chooseAuthButtonBox->setEnabled(false);
+        }
     }
 }
 
@@ -774,13 +888,21 @@ void SFAWidget::checkAuthResult(const int type, const int state)
  */
 void SFAWidget::syncAuthType(const QVariant &value)
 {
+    qDebug() << Q_FUNC_INFO << value;
+    int authType = value.toInt();
+
     QAbstractButton *btn = m_chooseAuthButtonBox->button(value.toInt());
-    if (btn)
+    if (btn) {
         btn->setChecked(true);
+        if (authType == AT_Custom && m_customAuth && !m_customAuth->showSwithButton()) {
+            btn->setVisible(false);
+        }
+    }
 }
 
 void SFAWidget::replaceWidget(AuthModule *authModule)
 {
+    m_currentAuthType = AuthType(authModule->authType());
     m_mainLayout->insertWidget(layout()->indexOf(m_userAvatar) + 3, authModule);
     authModule->show();
     setFocus();
@@ -790,12 +912,13 @@ void SFAWidget::replaceWidget(AuthModule *authModule)
         authModule->setFocus();
     m_lockButton->setEnabled(false);
     onRetryButtonVisibleChanged(false);
+    updateBlurEffectGeometry();
 }
 
 void SFAWidget::onRetryButtonVisibleChanged(bool visible)
 {
+    m_lockButton->setVisible(!visible && !(m_customAuth && AT_Custom == m_currentAuthType && !m_customAuth->showLockButton()));
     m_retryButton->setVisible(visible);
-    m_lockButton->setVisible(!visible);
 }
 
 void SFAWidget::setBioAuthStateVisible(AuthModule *authModule, bool visible)
@@ -816,6 +939,17 @@ int SFAWidget::getTopSpacing() const
     // 在低分辨率（高度<916）的时候，如果用户头像到屏幕顶端的距离为整个高度的35%，那么验证窗口整体是偏下的。
     // 计算居中时的顶部高度，用来保证验证窗口最起码是居中（在分辨率非常低的时候也无法保证，根据测试768是没问题的）。
     int centerTop = static_cast<int>((topLevelWidget()->geometry().height() - MIN_AUTH_WIDGET_HEIGHT) / 2);
+    if (m_customAuth) {
+        // 一般自定义的类型控件尺寸都会比较大，尽量保证能够居中显示。
+        // 根据头像、用户名、锁屏以及插件自身的高度来计算居中时顶部间隔
+        // 这是一个相对比较严格的高度，如果插件还是无法显示完整，或者界面偏下的话，只能插件调整content界面的大小了
+        int height = m_customAuth->showAvatar() ? m_userAvatar->height() + 10 : 0;
+        height += m_customAuth->showUserName() ? m_nameLabel->height() + 10 : 0;
+        height += m_customAuth->showLockButton() ? m_lockButton->height() + 10 : 0;
+
+        centerTop = static_cast<int>((topLevelWidget()->geometry().height() - height - m_customAuth->contentSize().height()) / 2);
+    }
+
     const int topHeight = qMin(calcTopHeight, centerTop);
 
     // 需要额外增加的顶部间隔高度 = 屏幕高度*0.35 - 时间控件高度 - 布局间隔 - 生物认证按钮底部间隔
@@ -832,9 +966,10 @@ int SFAWidget::getTopSpacing() const
 
 void SFAWidget::resizeEvent(QResizeEvent *event)
 {
-    AuthWidget::resizeEvent(event);
-
+    updateBlurEffectGeometry();
     updateSpaceItem();
+
+    AuthWidget::resizeEvent(event);
 }
 
 /**
@@ -860,6 +995,9 @@ void SFAWidget::updateFocus()
     for (int i = 0; i < m_mainLayout->layout()->count(); ++i) {
         AuthModule *authModule = qobject_cast<AuthModule *>(m_mainLayout->layout()->itemAt(i)->widget());
         if (authModule && authModule->authType() == m_chooseAuthButtonBox->checkedId()) {
+            if (authModule->authType() == AT_Custom && m_customAuth && !m_customAuth->showSwithButton()) {
+                return;
+            }
             setFocus();
             if (authModule->isLocked())
                 authModule->clearFocus();
@@ -877,3 +1015,78 @@ void SFAWidget::showEvent(QShowEvent *event)
 
     QTimer::singleShot(0, this, &SFAWidget::updateFocus);
 }
+
+void SFAWidget::updateBlurEffectGeometry()
+{
+    if (m_customAuth && AT_Custom == m_currentAuthType) {
+        QRect rect = this->rect();
+        // top
+        if (!m_customAuth->showAvatar()) {
+            if (m_customAuth->showUserName()) {
+                rect.setTop(m_nameLabel->geometry().top() - 10);
+            } else {
+                rect.setTop(m_customAuth->geometry().top() - 10);
+            }
+        } else {
+            rect.setTop(m_userAvatar->geometry().top() + m_userAvatar->height() / 2);
+        }
+        // bottom
+        if (m_user->expiredState() == User::ExpiredNormal) {
+            if (!m_customAuth->showLockButton()) {
+                rect.setBottom(m_customAuth->geometry().bottom() + 10);
+            } else {
+                rect.setBottom(m_lockButton->geometry().top() - 10);
+            }
+        } else {
+            rect.setBottom(m_expiredStateLabel->geometry().top() - 10);
+        }
+        m_blurEffectWidget->setGeometry(rect);
+        m_blurEffectWidget->update();
+    } else {
+        AuthWidget::updateBlurEffectGeometry();
+    }
+}
+
+void SFAWidget::initAccount()
+{
+    qDebug() << "Init switch button of account ";
+
+    /* 认证选择按钮 */
+    if (m_authButtons.contains(AT_None)) {
+        return;
+    }
+    DButtonBoxButton *btn = new DButtonBoxButton(QIcon(Password_Auth), QString(), this);
+    btn->setIconSize(AuthButtonIconSize);
+    btn->setFixedSize(AuthButtonSize);
+    btn->setFocusPolicy(Qt::NoFocus);
+    m_authButtons.insert(AT_None, btn);
+    connect(btn, &DButtonBoxButton::toggled, this, [this](const bool checked) {
+        if (checked) {
+            m_accountEdit->show();
+            m_lockButton->show();
+            m_frameDataBind->updateValue("SFAType", AT_None);
+            m_currentAuthType = AT_None;
+            setBioAuthStateVisible(nullptr, false);
+        } else {
+            m_accountEdit->hide();
+        }
+    });
+}
+
+void SFAWidget::onRequestChangeAuth(const int authType)
+{
+    qInfo() << Q_FUNC_INFO <<  authType;
+    if(!m_chooseAuthButtonBox->isEnabled() || m_currentAuthType != AT_Custom){
+        return;
+    }
+
+    if (!m_authButtons.contains(authType)) {
+        qDebug() << "onRequestChangeAuth no contain";
+        m_chooseAuthButtonBox->button(m_authButtons.firstKey())->toggled(true);
+        return ;
+    }
+
+    QAbstractButton *btn = m_chooseAuthButtonBox->button(authType);
+    if (btn)
+        emit btn->toggled(true);
+}
