@@ -38,6 +38,7 @@
 #include <DPushButton>
 #include <dimagebutton.h>
 #include <DConfig>
+#include <DRegionMonitor>
 
 #include <QEvent>
 #include <QGraphicsDropShadowEffect>
@@ -45,12 +46,14 @@
 #include <QPainter>
 #include <QWheelEvent>
 #include <QMenu>
+#include <QWindow>
 
 #define BUTTON_ICON_SIZE QSize(26,26)
 #define BUTTON_SIZE QSize(52,52)
 
 using namespace dss;
 DCORE_USE_NAMESPACE
+DGUI_USE_NAMESPACE
 
 bool FlotingButton::eventFilter(QObject *watch, QEvent *event)
 {
@@ -221,9 +224,11 @@ void ControlWidget::initUI()
     m_mainLayout->addWidget(m_switchUserBtn);
     m_mainLayout->addWidget(m_powerBtn);
 
-    QHash<QString, module::BaseModuleInterface *> modules = module::ModulesLoader::instance().moduleList();
-    for (module::BaseModuleInterface *module : modules.values()) {
-        addModule(module);
+    for (QSharedPointer<module::BaseModuleInterface> module : module::ModulesLoader::instance().moduleList()) {
+        if (module.isNull())
+            continue;
+
+        addModule(module.data());
     }
 
     updateLayout();
@@ -307,14 +312,18 @@ void ControlWidget::addModule(module::BaseModuleInterface *module)
         QAction *action = m_contextMenu->exec(QCursor::pos());
         if (action)
             trayModule->invokedMenuItem(action->data().toString(), true);
+
+        // 右键菜单隐藏后需要重新grab键盘，否则会导致快捷键重新生效
+        if (!m_model->isUseWayland()) {
+            QWindow *winHandle = topLevelWidget()->windowHandle();
+            if (!winHandle || !winHandle->setKeyboardGrabEnabled(true)) {
+                qWarning() << "Grab keyboard failed";
+            }
+        }
     });
 
     connect(button, &FlotingButton::requestShowTips, this, [ = ] {
         if (trayModule->itemTipsWidget()) {
-            if (m_model->isUseWayland() && m_tipsWidget->parent() != topLevelWidget()) {
-                // 顶层对象的窗口是override级别，需要将其设置为弹窗的父对象，否则无法显示出来。
-                m_tipsWidget->setParent(topLevelWidget());
-            }
             m_tipsWidget->setContent(trayModule->itemTipsWidget());
             m_tipsWidget->show(mapToGlobal(button->pos()).x() + button->width() / 2,mapToGlobal(button->pos()).y());
         }
@@ -547,10 +556,6 @@ void ControlWidget::setKBLayoutVisible()
     if (!m_arrowRectWidget->getContent()) {
         m_arrowRectWidget->setContent(m_kbLayoutListView);
     }
-    if (m_model->isUseWayland() && m_arrowRectWidget->parent() != topLevelWidget()) {
-        // 顶层对象的窗口是override级别，需要将其设置为弹窗的父对象，否则无法显示出来。
-        m_arrowRectWidget->setParent(topLevelWidget());
-    }
     m_arrowRectWidget->resize(m_kbLayoutListView->size() + QSize(0, 10));
 
     QPoint pos = QPoint(mapToGlobal(layoutButton->pos()).x() + layoutButton->width() / 2, mapToGlobal(layoutButton->pos()).y());
@@ -613,8 +618,8 @@ bool ControlWidget::eventFilter(QObject *watched, QEvent *event)
         }
     }
 
-    DFloatingButton *btn = dynamic_cast<DFloatingButton *>(watched);
-    if (m_btnList.contains(btn)) {
+    DFloatingButton *btn = qobject_cast<DFloatingButton *>(watched);
+    if (btn && m_btnList.contains(btn)) {
         if (event->type() == QEvent::Enter) {
             m_index = m_btnList.indexOf(btn);
         }
