@@ -70,7 +70,8 @@ FullscreenBackground::FullscreenBackground(SessionBaseModel *model, QWidget *par
         setWindowFlags(windowFlags() | Qt::FramelessWindowHint | Qt::Window);
 
         setAttribute(Qt::WA_NativeWindow); // 创建窗口 handle
-        windowHandle()->setProperty("_d_dwayland_window-type", "override"); // 禁止移动
+        // onScreenDisplay 低于override，高于tooltip，希望显示在锁屏上方的界面，均需要调整层级为onScreenDisplay或者override
+        windowHandle()->setProperty("_d_dwayland_window-type", "onScreenDisplay");
     }
 #endif
     frameList.append(this);
@@ -388,6 +389,9 @@ void FullscreenBackground::hideEvent(QHideEvent *event)
     if (m_model->isUseWayland()) {
         Q_EMIT requestDisableGlobalShortcutsForWayland(false);
     }
+
+    // 将content隐藏起来，下次锁屏拉起的时候显示鼠标所在屏幕，这样可以避免多屏显示认证界面（如果时序有问题的话）和 屏幕闪现认证界面的问题
+    m_content->hide();
     QWidget::hideEvent(event);
 }
 
