@@ -1,12 +1,10 @@
-#include <gtest/gtest.h>
-
-#include <QTest>
-#include <QLabel>
-#include <QSignalSpy>
-#include <QPushButton>
-
 #include "loginwindow.h"
 #include "sessionbasemodel.h"
+#include "userinfo.h"
+
+#include <QResizeEvent>
+
+#include <gtest/gtest.h>
 
 class UT_LoginWindow : public testing::Test
 {
@@ -15,14 +13,16 @@ protected:
     void TearDown() override;
 
     SessionBaseModel *m_sessionBaseModel;
+    std::shared_ptr<User> m_user;
     LoginWindow *m_loginwindow;
 };
 
 void UT_LoginWindow::SetUp()
 {
-    m_sessionBaseModel = new SessionBaseModel(SessionBaseModel::AuthType::LightdmType);
+    m_sessionBaseModel = new SessionBaseModel();
+    m_user = std::make_shared<User>();
+    m_sessionBaseModel->updateCurrentUser(m_user);
     m_loginwindow = new LoginWindow(m_sessionBaseModel);
-
 }
 
 void UT_LoginWindow::TearDown()
@@ -31,18 +31,13 @@ void UT_LoginWindow::TearDown()
     delete m_loginwindow;
 }
 
-TEST_F(UT_LoginWindow, coverage_main)
+TEST_F(UT_LoginWindow, Validity)
 {
     ASSERT_NE(m_loginwindow, nullptr);
 }
 
-TEST_F(UT_LoginWindow, coverage_isValid)
+TEST_F(UT_LoginWindow, Visibility)
 {
-
-}
-
-TEST_F(UT_LoginWindow, buttonClicked)
-{
-
-
+    m_loginwindow->show();
+    m_loginwindow->hide();
 }
